import { __decorate } from "tslib";
import { Component } from 'vue-property-decorator';
import { isBoolean, isFunction, capitalize, getControl } from 'handie-vue';
import { FormViewStructuralWidget } from 'handie-vue/dist/widgets';
import defaultBehaviors from './behavior';
let FormViewWidget = class FormViewWidget extends FormViewStructuralWidget {
    isActionBarOutside() {
        if (isBoolean(this.config.actionBarOutside)) {
            return this.config.actionBarOutside;
        }
        return isBoolean(this.getBehavior('actionBarOutside'))
            ? this.getBehavior('actionBarOutside')
            : this.getCommonBehavior('view.objectViewActionBarOutside', false);
    }
    resolveActionBarAlignment() {
        if (this.config.actionBarAlignment) {
            return this.config.actionBarAlignment;
        }
        return (this.getBehavior('actionBarAlignment') ||
            this.getCommonBehavior('view.objectViewActionBarAlignment', 'left'));
    }
    initFormViewContextEvents() {
        if (this.config.readonly === true) {
            return;
        }
        const newOne = this.isNewOne();
        const { gotoListView, listViewRouteName = `${this.$$module.getModuleName()}List`, successMessage = `${newOne ? '添加' : '修改'}成功`, } = this.config;
        const callback = gotoListView !== false
            ? () => this.$$history.push({ name: listViewRouteName, params: this.$$route.params })
            : () => this.$$app.success(isFunction(successMessage)
                ? successMessage(this.value)
                : successMessage);
        this.on('submit', () => {
            this.$$view.setBusy(true);
            if (newOne) {
                this.$$view
                    .insert(this.value, callback, message => this.$$app.error(message))
                    .finally(() => this.$$view.setBusy(false));
            }
            else {
                this.$$view
                    .update(this.value, callback, message => this.$$app.error(message))
                    .finally(() => this.$$view.setBusy(false));
            }
        });
    }
    render(h) {
        const outside = this.isActionBarOutside();
        const readonly = this.config.readonly === true;
        const actionBar = this.renderActionBar({
            className: this.$style['FormViewWidget-actionBar'],
            executors: {
                [this.getCommonBehavior('action.cancelAction')]: () => this.$$history.push({
                    name: this.config.listViewRouteName || `${this.$$module.getModuleName()}List`,
                }),
            },
            readonly,
        });
        return h(getControl('Wait'), {
            props: {
                className: [
                    this.$style.FormViewWidget,
                    this.$style[`FormViewWidget--actionBar${capitalize(this.resolveActionBarAlignment())}`],
                    { [this.$style['FormViewWidget--actionBarOutside']]: outside },
                    this.config.className,
                ],
                nativeStyle: this.getStyle(),
                busy: this.loading,
            },
        }, outside
            ? [
                h('div', { class: this.$style['FormViewWidget-formContainer'] }, [
                    this.renderForm({ className: this.$style['FormViewWidget-form'], readonly }),
                ]),
                actionBar,
            ]
            : [
                this.renderForm({
                    className: this.$style['FormViewWidget-form'],
                    readonly,
                    children: [actionBar],
                }),
            ]);
    }
    created() {
        this.setBehaviors('view.form', defaultBehaviors);
        this.initFormViewContextEvents();
        this.fetchData();
    }
};
FormViewWidget = __decorate([
    Component
], FormViewWidget);
export default FormViewWidget;
